"use strict";

import axios from 'axios';

// create an axios instance
const service = axios.create({
  baseURL: process.env.API_BASE,
  // request timeout
  timeout: 150000
});

// request interceptor
service.interceptors.request.use(
    function (config) {
      // TODO set accessToken with request header
      // config.headers['accessToken'] = getToken();
      // config.headers['refreshToken'] = getRefreshToken();
      // fixed GET request method caching problem
      config.headers['Cache-Control'] = 'no-cache';
      config.headers['Pragma'] = 'no-cache';
      // console.log('Service interceptors request config > ', config);
      /** 解决IE浏览器9+ 提交请求时，未填写的项目传递到后台为空字符串，无法通过验证的问题. 2019-3-20 start **/
      if(config.method == 'get'){
        if(config.params){
          for (var i in config.params){
            if(typeof(config.params[i]) == "string"){
              config.params[i] = config.params[i] == "" ? undefined : config.params[i]
            }
          }
          console.log(config.params,'当前数据get')
        }
      }else if (config.method == 'post' || config.method == 'put'){
        if(config.data){
          for (var i in config.data){
            if(typeof(config.data[i]) == "string"){
              config.data[i] = config.data[i] == "" ? undefined : config.data[i]
            }
          }
          console.log(config.data,'当前数据 data put/post')
        }
      }
      /** 解决IE浏览器9+ 提交请求时，未填写的项目传递到后台为空字符串，无法通过验证的问题. 2019-3-20 end **/
      return config
    },
    function (error) {
      //request error
      // console.log('Service interceptors request error > ', error);
      Promise.reject(error)
    }
);

// respone interceptor
service.interceptors.response.use(
    function (response) {
      console.log('Service interceptors url>', response.config.url, 'response >', response);
      return response;
    },
    function (error) {
      console.log('Service interceptors url>', error.config.url, 'error >', error, error.response);
      let tipError = false;
      // TODO Reservation processing error response
      if (error && error.response) {
        switch (error.response.status) {
          case 400:
            tipError = false;
            break;
          case 401:
            tipError = false;
            break;
          case 403:
            tipError = false;
            if (error.response.data) {
              if (error.response.data.code === 'WEB_ACCESS_AUTH_REQUIRED') {
                window.location.href = '/sign/in';
              }
              if (error.response.data.code === 'WEB_ACCESS_DENIED') {
                error.message = error.response.data.message;
                tipError = true;
              }
            }
            break;
          case 404:
            tipError = false;
            break;
          case 405:
            tipError = false;
            break;
          case 409:
            tipError = false;
            break;
          case 422:
            tipError = false;
            break;
          case 500:
            error.message = '服务器内部错误';
            tipError = true;
            break;
          default:
            error.message = '服务器内部错误';
            tipError = true;
            break;
        }
      }
      if (tipError) {
        // TODO error tip
        console.error('request tip errors > ', {
          message: error.message,
          type: 'error',
          duration: 5 * 1000
        })
      }
      return Promise.reject(error)
    });

export default service
