import Vue from 'vue'
import VueRouter from 'vue-router'
/** Default layout **/
import _DefaultLayout from './basement/layout/default'
/** Guide layout **/
import _GuideLayout from './basement/layout/guide'
/** Portal layout **/
import _PortalLayout from './basement/layout/portal'
/** Console layout **/
import _ConsoleLayout from './basement/layout/console'
/** Govt layout **/
import _GovtLayout from './basement/layout/govt'
/** Admin layout **/
import _AdminLayout from './basement/layout/admin'

/** leadingGroup layout **/
import _LeadingGroup from './basement/layout/leadingGroup'

/** Screen layout **/
import _ScreenLayout from './basement/layout/screen'
/** Jumbotron layout **/
import _JumbotronLayout1 from './basement/layout/jumbotron/jumbotron1'
import _JumbotronLayout2 from './basement/layout/jumbotron/jumbotron2'
import _JumbotronLayout3 from './basement/layout/jumbotron/jumbotron3'
import _JumbotronLayout4 from './basement/layout/jumbotron/jumbotron4'
/** Error Components**/
import _ERROR_401 from './basement/error/401'
import _ERROR_403 from './basement/error/403'
import _ERROR_404 from './basement/error/404'
import _ERROR_500 from './basement/error/500'

/** Laze loading mode **/
console.log('Main process.env > ', process.env);
const _import = require('./basement/router/_import_' + (process.env.LAZE_MODE ? 'lazeload' : 'require'));

Vue.use(VueRouter);

export const _ConstantRouterMap = [
  // Error
  {
    path: '/error',
    name: 'error',
    component: _ScreenLayout,
    meta: {title: 'ERROR', hidden: true},
    children: [
      {path: '401', name: '401', component: _ERROR_401, meta: {title: '401', hidden: true}},
      {path: '403', name: '403', component: _ERROR_403, meta: {title: '403', hidden: true}},
      {path: '404', name: '404', component: _ERROR_404, meta: {title: '404', hidden: true}},
      {path: '500', name: '500', component: _ERROR_500, meta: {title: '500', hidden: true}}
    ]
  }
];

const _Router = new VueRouter({
  base: '/',
  mode: 'history', // require service support
  scrollBehavior: () => ({y: 0}),
  routes: _ConstantRouterMap
});

export default _Router;

export const _AsyncRouterMap = [
  //  Index
  {
    path: '',
    name: 'index',
    component: _DefaultLayout,
    meta: {title: '首页', hidden: false},
    children: [
      {
        path: 'dashboard',
        name: 'dashboard',
        component: _import('sample/index'),
        meta: {title: 'Dashboard', hidden: false}
      },
      {
        path: 'hello',
        name: 'hello',
        component: _import('sample/hello'),
        meta: {title: 'Hello-World', hidden: false}
      }
    ]
  },
  //  Guide
  {
    path: '/guide',
    name: 'guide',
    component: _GuideLayout,
    meta: {title: 'Guide', hidden: true},
    children: [
      {
        path: 'todo',
        name: 'guide_todo',
        component: _import('guide/todo'),
        meta: {title: 'TODO', hidden: false}
      },
      {
        path: 'fe/:chapter/:view',
        name: 'guide_fe',
        component: _import('guide/fe/index'),
        meta: {title: 'Docs', hidden: false}
      },
      {
        path: 'io/:chapter/:view',
        name: 'guide_io',
        component: _import('guide/io/index'),
        meta: {title: 'Docs', hidden: false}
      }
    ]
  },
  //  Sample
  {
    path: '/sample',
    name: 'sample',
    component: _GuideLayout,
    meta: {title: 'Sample', hidden: true},
    children: [
      {
        path: 'fe/form',
        name: 'fe_sample_form',
        component: _import('sample/fe/form'),
        meta: {title: 'Form', hidden: false}
      },
      {
        path: 'fe/form/grid',
        name: 'fe_sample_form_grid',
        component: _import('sample/fe/form-grid'),
        meta: {title: 'Form-Grid', hidden: false}
      },
      {
        path: 'fe/form/inline',
        name: 'fe_sample_form_inline',
        component: _import('sample/fe/form-inline'),
        meta: {title: 'Form-Inline', hidden: false}
      },
      {
        path: 'fe/grid',
        name: 'fe_sample_grid',
        component: _import('sample/fe/grid'),
        meta: {title: 'Grid-View', hidden: false}
      },
      {
        path: 'fe/tabs',
        name: 'fe_sample_tabs',
        component: _import('sample/fe/tabs'),
        meta: {title: 'Tabs-View', hidden: false}
      },
      {
        path: 'fe/modal',
        name: 'fe_sample_modal',
        component: _import('sample/fe/modal'),
        meta: {title: 'Modal', hidden: false}
      },
      {
        path: 'fe/date-picker',
        name: 'fe_sample_date_pick',
        component: _import('sample/fe/date-picker'),
        meta: {title: 'DatePicker', hidden: false}
      },
      {
        path: 'fe/selector',
        name: 'fe_sample_selector',
        component: _import('sample/fe/selector'),
        meta: {title: 'Selector', hidden: false}
      },
      {
        path: 'fe/tinymce',
        name: 'fe_sample_tinymce',
        component: _import('sample/fe/tinymce'),
        meta: {title: 'Tinymce', hidden: false}
      },
      {
        path: 'fe/mavon',
        name: 'fe_sample_mavon',
        component: _import('sample/fe/mavon'),
        meta: {title: 'Mavon', hidden: false}
      },
      {
        path: 'fe/calendar',
        name: 'fe_sample_calendar',
        component: _import('sample/fe/calendar'),
        meta: {title: 'Calendar', hidden: false}
      }
    ]
  },
  //  Portal
  {
    path: '/portal',
    name: 'portal',
    component: _PortalLayout,
    meta: {title: 'Portal', hidden: true},
    children: []
  },
  //  LeadingGroup
  {
    path: '/leadingGroup',
    name: 'leadingGroup',
    component: _LeadingGroup,
    meta: {title: 'LeadingGroup', hidden: true},
    children: []
  },
  //  Console
  {
    path: '/console',
    name: 'console',
    component: _ConsoleLayout,
    meta: {title: 'Console', hidden: true},
    children: []
  },
  //  Govt
  {
    path: '/govt',
    name: 'govt',
    component: _GovtLayout,
    meta: {title: 'Govt', hidden: true},
    children: []
  },
  //  Admin
  {
    path: '/admin',
    name: 'admin',
    component: _AdminLayout,
    meta: {title: 'Admin', hidden: true},
    children: []
  },
  //  Jumbotron
  {
    path: '/jumbotron1',
    name: 'jumbotron1',
    component: _JumbotronLayout1,
    meta: {title: 'Jumbotron1', hidden: true},
    children: []
  },
  //  Jumbotron
  {
    path: '/jumbotron2',
    name: 'jumbotron2',
    component: _JumbotronLayout2,
    meta: {title: 'Jumbotron2', hidden: true},
    children: []
  },
  {
    path: '/jumbotron3',
    name: 'jumbotron3',
    component: _JumbotronLayout3,
    meta: {title: 'Jumbotron3', hidden: true},
    children: []
  },
  {
    path: '/jumbotron4',
    name: 'jumbotron4',
    component: _JumbotronLayout4,
    meta: {title: 'Jumbotron4', hidden: true},
    children: []
  },
  {path: '*', redirect: '/error/404', hidden: true}
];
